polyfemos.tests.test_python_packages — polyfemos 0.3.29 documentation

# polyfemos.tests.test_python_packages

Checks if all packages required by polyfemos are installed.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.tests.test_python_packages.` `main`()

  Checks if all packages required by polyfemos are installed.

`polyfemos.tests.test_python_packages.` `package_version`(pkg, required)
  Parameters

    - pkg (str) – package name

    - required (str) – version which works with polyfemos

  Return type

    str, str, str

  Returns

    package name, installed version, required version

`polyfemos.tests.test_python_packages.` `print_line`(*args)

  Prints given `args`.

`polyfemos.tests.test_python_packages.` `python_version`(pkg, required)
  Parameters

    - pkg (str) – python name

    - required (str) – python version which works with polyfemos

  Return type

    str, str, str

  Returns

    python name, installed python version, required python version

`polyfemos.tests.test_python_packages.` `uwsgi_version`(pkg, required)
  Parameters

    - pkg (str) – uwsgi name

    - required (str) – uwsgi version which works with polyfemos

  Return type

    str, str, str

  Returns

    uwsgi name, installed uwsgi version, required uwsgi version